@@ -1,4 +1,10 @@
-def crypt(self, code):
+def encrypt(self: str, code: str | int) -> str:
+	""" function to encrypt
+
+	:param self: Text to encrypt
+	:param code: Code used to encrypt
+	:return: Encrypted text
+	"""
 	counter = 0
 	text = ""
 	for c in self:
@@ -16,7 +22,7 @@ def crypt(self, code):
 	return salt_text
 
 
-def decrypt(self, code):
+def decrypt(self: str, code: str | int) -> str:
 	text = ""
 	j = 0
 	while j < len(self):
